@@ -125,15 +125,29 @@ class Essays(object):
 
 Essays._init_essay_properties()
 
+_profile_details_xpb = xpb.div.with_classes('profile_details')
+def detail(name, setter=False):
+    dd_xpb = _profile_details_xpb.dd(id='ajax_{0}'.format(name))
+    @property
+    def detail_property(self):
+        dd_xpb.get_text_(self._profile_tree)
+    if setter:
+        return detail_property.setter
+    return detail_property
+
+class Details(object):
+
+    def __init__(self, session, profile_tree):
+        self._session = session
+        self._profile_tree = profile_tree
+
 
 class Profile(object):
 
     def __init__(self, session, username, **kwargs):
         self._session = session
         self.username = username
-        self._question_fetcher = QuestionFetcher(session, username,
-                                                 is_user=self.is_logged_in_user)
-        self.questions = util.Fetchable(self._question_fetcher)
+        self.questions = self.question_fetchable()
 
     def refresh(self, reload=True):
         util.cached_property.bust_caches(self)
@@ -146,9 +160,7 @@ class Profile(object):
 
     @util.cached_property
     def _profile_response(self):
-        return self._session.get(
-            'https://www.okcupid.com/profile/{0}'.format(self.username)
-        ).content
+        return self._session.okc_get(u'profile/{0}'.format(self.username)).content
 
     @util.cached_property
     def _profile_tree(self):
@@ -171,12 +183,14 @@ class Profile(object):
         return helpers.get_authcode(self._profile_tree)
 
     @util.cached_property
-    def picture_uris(self):
+    def photo_infos(self):
         pics_request = self._session.okc_get(
-            'profile/{0}/photos?cf=profile'.format(self.username)
+            u'profile/{0}/photos#0'.format(self.username)
         )
         pics_tree = html.fromstring(pics_request.content.decode('utf8'))
-        return xpb.div(id='album_0').img.select_attribute_('src', pics_tree)
+        from . import photo
+        return map(photo.Info.from_cdn_uri,
+                   xpb.div(id='album_0').img.select_attribute_('src', pics_tree))
 
     _rating_xpb = xpb.div(id='rating').ul(id='personality-rating').li.\
                   with_class('current-rating')
@@ -299,18 +313,8 @@ class Profile(object):
             'vote_type': 'personality',
             'score': rating,
         }
-        headers = {
-            'accept': 'text/javascript, text/html, application/xml, '
-            'text/xml, */*',
-            'accept-encoding': 'gzip,deflate',
-            'accept-language': 'en-US,en;q=0.8',
-            'content-type': 'application/x-www-form-urlencoded; charset=UTF-8',
-            'origin': 'https://www.okcupid.com',
-            'x-prototype-version': 1.7,
-            'x-requested-with': 'XMLHttpRequest',
-        }
-        response = self._session.okc_post('vote_handler', data=parameters,
-                                          headers=headers)
+        response = self._session.okc_post('vote_handler',
+                                          data=parameters)
         response_json = response.json()
         log_function = log.info if response_json.get('status', False) \
                        else log.error
@@ -319,6 +323,12 @@ class Profile(object):
                                        'headers': dict(self._session.headers)}))
         self.refresh(reload=False)
 
+    def question_fetchable(self, **kwargs):
+        return util.Fetchable(QuestionFetcher(
+            self._session, self.username,
+            is_user=self.is_logged_in_user, **kwargs
+        ))
+
     def __eq__(self, other):
         self.username.lower() == other.username.lower()
 
